# vb domain

```{toctree}
md
rest
modules
genindex
```

## Cross-reference

- {ref}`modules:module1.sampleprocedure`
- {vb:function}`cd94f36.sampleprocedure`

% {vb:function}`e52559a.getid`

% {vb:function}`cd94f36.ec2a54`

% - <project:md.md#module1-getid> NG
% - [aaa](md.md#module1-getid) NG

- <project:#md.d0ec0de3>
- <project:#module1.sampleprocedure> OK

% <project:#cd94f36.sampleprocedure> OK

- [aaa](#module1.sampleprocedure) OK
- [aaa](#cd94f36.sampleprocedure) OK
- [](#cd94f36.sampleprocedure) OK

% <project:modules.rst#module1-sampleprocedure> NG

% [aaa](modules.rst#module1-sampleprocedure) NG

% [](modules.rst#module1-sampleprocedure)
